@@ -1,4 +1,5 @@
 from .element import Element
+from .app import callbackRegistry
 
 class Card(Element):
     """A white-boxed container to hold content in sections
@@ -64,11 +65,41 @@ class Paragraph(Element):
     def __init__(self, text='', id=None, color=None):
         super().__init__('Paragraph', text=text, id=id, color=color)
 
+class Group(Element):
+    """Group a part of elements in a div element"""
+    def __init__(self, content=[], name='', id=None):
+        super().__init__('Group', content=content, name=name, id=id)
+
+class Tabs(Element):
+    """Display a group of tabs. Each content item is a tab
+
+    Args:
+        position: top | left | bottom | right, where the tab is (decide if it's horizontal or vertical)
+        format: line | card - the style of the tabs
+        size: default | large | small
+    """
+    def __init__(self, content=[], position='top', format='line', size='default', id=None):
+        super().__init__('Tabs', content=content, format=format, style={'position': position}, size=size, id=id)
+
 class RawHTML(Element):
     """Display a (dangerous) HTML to the page"""
     def __init__(self, text='', id=None):
         super().__init__('RawHTML', text=text, id=id)
 
+class Timer(Element):
+    """Group a part of elements in a div element"""
+    def __init__(self, interval=3, on_fire=None, data=None, id=None):
+        on_change_uuid = callbackRegistry.uuid_for_callback(on_fire)
+        super().__init__('Timer', on_change=on_change_uuid, interval=interval, data=data, id=id)
+
+class Image(Element):
+    """Display an image
+        url: the src of the image
+        title: the alt text of the image
+    """
+    def __init__(self, url='', title='', width=None, id=None):
+        super().__init__('Image', url=url, title=title, style={'width': width}, id=id)
+
 class Row(Element):
     """Display a row with multiple Columns for layout purpose
 
